#
# spec file for package python-scikit-dsp-comm
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
%define skip_python36 1
Name:           python-scikit-dsp-comm
Version:        1.2.0
Release:        3.12
Summary:        DSP and Comm package for Python
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/mwickert/scikit-dsp-comm
Source0:        https://files.pythonhosted.org/packages/source/s/scikit-dsp-comm/scikit-dsp-comm-%{version}.tar.gz
Source100:      python-scikit-dsp-comm-rpmlintrc
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-matplotlib
Requires:       python-numpy
Requires:       python-scipy
Recommends:     python-PyAudio
Recommends:     python-colorama
Recommends:     python-ipywidgets
Recommends:     python-pyrtlsdr
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module tox}
# /SECTION
%python_subpackages

%description
This package is a collection of functions and classes to support
signal processing and communications theory teaching and research.
The foundation for this package is scipy.signal.

%prep
%setup -q -n scikit-dsp-comm-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_expand chmod a-x %{buildroot}%{$python_sitelib}/sk_dsp_comm/*.txt

%files %{python_files}
%doc README.md
%license LICENSE.md
%{python_sitelib}/*

%changelog
* Wed Oct  6 2021 Steve Kowalik <steven.kowalik@suse.com>
- Remove nose BuildRequires.
* Sun Feb 14 2021 Dirk Müller <dmueller@suse.com>
- skip python 3.6 (no scipy anymore)
* Wed Jul 15 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.2.0
  * New pulse shaping
  * Print statements changed to logging and warnings
* Mon Jun 29 2020 Todd R <toddrme2178@gmail.com>
- Update to version 1.1.0
  * Added imports to examples
  * Adding FIR and IIR filter design notebook
  * Adding FIR csv file
  * Adding a device check inside pyaudio_helper before going to pyaudio;
  * Adding audio resources for Real-Time ipynb
  * Adding base stripped ipynb for pyaudio example
  * Adding block diagram figure and updated notebook
  * Adding final images to notebook
  * Adding full name for music buffer plot image
  * Adding images to manifest so they will show up on pypi docs next time.
  * Adding ipykernel; missing requirement for jupyter notebooks
  * Adding ipynb with changes for paths to files; first widget image added
  * Adding jupyter notebook and toctree setup
  * Adding mic noise file
  * Adding multirate processing notebook
  * Adding music buffer capture plot to notebook
  * Adding nb examples to a toctree
  * Adding nbsphinx setup
  * Adding new cell for random seed
  * Adding path change for three band equalizer csv
  * Adding readme file to docs
  * Adding reqs for widget building
  * Adding spaces for proper latex parsing
  * Adding the Convolutional Codes notebook to the docs
  * Adding three band equalizer csv file
  * Adds a check for integer values of M only for downsample; Fixes: #16
  * Also need ipywidgets
  * Bumping version for new releaes with viterbi rate 1/3
  * FIR and IIR Filter Design gets its own section
  * Fixing doc strings for viterbi
  * Fixing in out check function and warning text
  * Include license in sdists
  * Include license in wheels
  * Initializing class elements to blank for accessors
  * Making changes to PLL_cbb docstring
  * Making return string doc more explicit, refs: #12
  * Minimum matplotlib requirement added for rtd
  * Modifying PLL doc string
  * Modifying doc string to remove indents
  * Modifying phase step doc string
  * Modifying time step doc string
  * Moving print lines to logging output at debug level
  * New file to hold jupyter notebook example links
  * Now using one file for versioning project; setup and docs
  * Optfir module functionality was rewritten into fir_design_helper
  * Raising warnings to errors to force correct usage of devices
  * Refactoring test to deconflict naming for rate 1/3
  * Remove if statement from viterbi_decoder. Get length from rate denomi…
  * Remove rate if statements from bm_calc. Get length from rate denomina…
  * Removed optfir from __init__.py.
  * Removing optfir dependency and fix mlab.find warnings.
  * Removing optfir from docs
  * Require 0/1 integers for hard decision Viterbi decoding, add examples…
  * Test for saturation limit in simpleQuant.
  * Use a ValueError to raise an error instead of exiting a users process
  * Use fraction for rate instead of string
  * Using dc MPSK_bb which has fixes for Ns
  * Using markdown long description instead of converting with pandoc
  * extend to rate 1/3 convolutional codes
  * from future needs to be moved to first line
  * ignore vs code JSON file.
  * implement two channel (stereo) in loop_audio class
  * only_directive is builtin now so removing from extensions list
  * using Regexp for 2.7 compat
* Fri Nov  2 2018 Todd R <toddrme2178@gmail.com>
- Initial version
